@@ -30,33 +30,33 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import au.com.bytecode.opencsv.CSVWriter;
-import ca.ubc.cs.beta.aclib.algorithmrun.AlgorithmRun;
-import ca.ubc.cs.beta.aclib.configspace.ParamConfiguration;
-import ca.ubc.cs.beta.aclib.configspace.ParamConfiguration.StringFormat;
-import ca.ubc.cs.beta.aclib.exceptions.DeveloperMadeABooBooException;
-import ca.ubc.cs.beta.aclib.exceptions.DuplicateRunException;
-import ca.ubc.cs.beta.aclib.execconfig.AlgorithmExecutionConfig;
-import ca.ubc.cs.beta.aclib.objectives.OverallObjective;
-import ca.ubc.cs.beta.aclib.objectives.RunObjective;
-import ca.ubc.cs.beta.aclib.probleminstance.ProblemInstance;
-import ca.ubc.cs.beta.aclib.probleminstance.ProblemInstanceSeedPair;
-import ca.ubc.cs.beta.aclib.runconfig.RunConfig;
-import ca.ubc.cs.beta.aclib.runhistory.NewRunHistory;
-import ca.ubc.cs.beta.aclib.runhistory.RunHistory;
-import ca.ubc.cs.beta.aclib.seedgenerator.InstanceSeedGenerator;
-import ca.ubc.cs.beta.aclib.seedgenerator.RandomInstanceSeedGenerator;
-import ca.ubc.cs.beta.aclib.seedgenerator.SetInstanceSeedGenerator;
-import ca.ubc.cs.beta.aclib.smac.ValidationOptions;
-import ca.ubc.cs.beta.aclib.smac.ValidationRoundingMode;
-import ca.ubc.cs.beta.aclib.state.StateFactory;
-import ca.ubc.cs.beta.aclib.state.StateSerializer;
-import ca.ubc.cs.beta.aclib.state.legacy.LegacyStateFactory;
-import ca.ubc.cs.beta.aclib.targetalgorithmevaluator.TargetAlgorithmEvaluatorCallback;
-import ca.ubc.cs.beta.aclib.targetalgorithmevaluator.TargetAlgorithmEvaluator;
-import ca.ubc.cs.beta.aclib.targetalgorithmevaluator.WaitableTAECallback;
-import ca.ubc.cs.beta.aclib.targetalgorithmevaluator.base.cli.CommandLineAlgorithmRun;
-import ca.ubc.cs.beta.aclib.trajectoryfile.TrajectoryFile;
-import ca.ubc.cs.beta.aclib.trajectoryfile.TrajectoryFileEntry;
+import ca.ubc.cs.beta.aeatk.algorithmexecutionconfiguration.AlgorithmExecutionConfiguration;
+import ca.ubc.cs.beta.aeatk.algorithmrunconfiguration.AlgorithmRunConfiguration;
+import ca.ubc.cs.beta.aeatk.algorithmrunresult.AlgorithmRunResult;
+import ca.ubc.cs.beta.aeatk.exceptions.DeveloperMadeABooBooException;
+import ca.ubc.cs.beta.aeatk.exceptions.DuplicateRunException;
+import ca.ubc.cs.beta.aeatk.objectives.OverallObjective;
+import ca.ubc.cs.beta.aeatk.objectives.RunObjective;
+import ca.ubc.cs.beta.aeatk.parameterconfigurationspace.ParameterConfiguration;
+import ca.ubc.cs.beta.aeatk.parameterconfigurationspace.ParameterConfiguration.ParameterStringFormat;
+import ca.ubc.cs.beta.aeatk.probleminstance.ProblemInstance;
+import ca.ubc.cs.beta.aeatk.probleminstance.ProblemInstanceSeedPair;
+import ca.ubc.cs.beta.aeatk.probleminstance.seedgenerator.InstanceSeedGenerator;
+import ca.ubc.cs.beta.aeatk.probleminstance.seedgenerator.RandomInstanceSeedGenerator;
+import ca.ubc.cs.beta.aeatk.probleminstance.seedgenerator.SetInstanceSeedGenerator;
+import ca.ubc.cs.beta.aeatk.runhistory.NewRunHistory;
+import ca.ubc.cs.beta.aeatk.runhistory.RunHistory;
+import ca.ubc.cs.beta.aeatk.smac.ValidationOptions;
+import ca.ubc.cs.beta.aeatk.smac.ValidationRoundingMode;
+import ca.ubc.cs.beta.aeatk.state.StateFactory;
+import ca.ubc.cs.beta.aeatk.state.StateSerializer;
+import ca.ubc.cs.beta.aeatk.state.legacy.LegacyStateFactory;
+import ca.ubc.cs.beta.aeatk.targetalgorithmevaluator.TargetAlgorithmEvaluator;
+import ca.ubc.cs.beta.aeatk.targetalgorithmevaluator.TargetAlgorithmEvaluatorCallback;
+import ca.ubc.cs.beta.aeatk.targetalgorithmevaluator.WaitableTAECallback;
+import ca.ubc.cs.beta.aeatk.targetalgorithmevaluator.base.cli.CommandLineAlgorithmRun;
+import ca.ubc.cs.beta.aeatk.trajectoryfile.TrajectoryFile;
+import ca.ubc.cs.beta.aeatk.trajectoryfile.TrajectoryFileEntry;
 
 
 
@@ -71,10 +71,10 @@ public class Validator {
 	}
 		*/
 
-	public SortedMap<TrajectoryFileEntry, Double>  simpleValidate(List<ProblemInstance> testInstances, final ValidationOptions options,final double cutoffTime,final InstanceSeedGenerator testInstGen,final TargetAlgorithmEvaluator validatingTae, 
+	public SortedMap<TrajectoryFileEntry, ValidationResult>  simpleValidate(List<ProblemInstance> testInstances, final ValidationOptions options,final double cutoffTime,final InstanceSeedGenerator testInstGen,final TargetAlgorithmEvaluator validatingTae, 
 			final String outputDir,
 			final RunObjective runObj,
-			final OverallObjective intraInstanceObjective, final OverallObjective interInstanceObjective,  TrajectoryFile trajFile, boolean waitForRuns, int cores, AlgorithmExecutionConfig execConfig) 
+			final OverallObjective intraInstanceObjective, final OverallObjective interInstanceObjective,  TrajectoryFile trajFile, boolean waitForRuns, int cores, AlgorithmExecutionConfiguration execConfig) 
 			{
 
 				if(options.useWallClockTime)
@@ -95,11 +95,11 @@ public class Validator {
 				} else
 				{
 					
-					Set<ParamConfiguration> configs = new HashSet<ParamConfiguration>();
+					Set<ParameterConfiguration> configs = new HashSet<ParameterConfiguration>();
 					
-					for(RunConfig rc : runs.runConfigs)
+					for(AlgorithmRunConfiguration rc : runs.runConfigs)
 					{
-						configs.add(rc.getParamConfiguration());
+						configs.add(rc.getParameterConfiguration());
 					}
 					log.info("Validation needs {} algorithm runs to validate {} configurations found, each on {} problem instance seed pairs", runs.runConfigs.size(), configs.size(),pisps.size());
 					
@@ -141,7 +141,7 @@ public class Validator {
 
 	public void  multiValidate(List<ProblemInstance> testInstances, final ValidationOptions options,final double cutoffTime,final InstanceSeedGenerator testInstGen,final TargetAlgorithmEvaluator validatingTae,
 			final RunObjective runObj,
-			final OverallObjective intraInstanceObjective, final OverallObjective interInstanceObjective,  final Set<TrajectoryFile> tfes, boolean waitForRuns, int cores, AlgorithmExecutionConfig execConfig) 
+			final OverallObjective intraInstanceObjective, final OverallObjective interInstanceObjective,  final Set<TrajectoryFile> tfes, boolean waitForRuns, int cores, AlgorithmExecutionConfiguration execConfig) 
 			{
 		
 		
@@ -162,14 +162,14 @@ public class Validator {
 				}
 				for(TrajectoryFile tfe: tfes)
 				{
-					runs.add(validateStage(pisps, options, cutoffTime, runObj, intraInstanceObjective, interInstanceObjective, tfe,execConfig));
+					runs.add(validateStage(pisps, options, cutoffTime, runObj, intraInstanceObjective, interInstanceObjective, tfe, execConfig));
 				}
 
 				
-				Set<RunConfig> runConfigs = new LinkedHashSet<RunConfig>();
-				Set<ParamConfiguration> configs = new HashSet<ParamConfiguration>();
+				Set<AlgorithmRunConfiguration> runConfigs = new LinkedHashSet<AlgorithmRunConfiguration>();
+				Set<ParameterConfiguration> configs = new HashSet<ParameterConfiguration>();
 				
-				final Map<WaitableTAECallback, List<RunConfig>> callbacksToSchedule = new LinkedHashMap<WaitableTAECallback, List<RunConfig>>();
+				final Map<WaitableTAECallback, List<AlgorithmRunConfiguration>> callbacksToSchedule = new LinkedHashMap<WaitableTAECallback, List<AlgorithmRunConfiguration>>();
 				for(ValidationRuns run : runs)
 				{
 					if(run.done)
@@ -177,17 +177,17 @@ public class Validator {
 						continue;
 					}
 					
-					for(RunConfig rc : run.runConfigs)
+					for(AlgorithmRunConfiguration rc : run.runConfigs)
 					{
 						runConfigs.add(rc);
-						configs.add(rc.getParamConfiguration());
+						configs.add(rc.getParameterConfiguration());
 					}
 					
 					callbacksToSchedule.put(run.callback, run.runConfigs);
 					
 				}
 				
-				List<RunConfig> runConfigsToRun = new ArrayList<RunConfig>(runConfigs);
+				List<AlgorithmRunConfiguration> runConfigsToRun = new ArrayList<AlgorithmRunConfiguration>(runConfigs);
 
 				log.info("Validation needs {} algorithm runs to validate {} configurations found, each on {} problem instance seed pairs", runConfigsToRun.size(), configs.size(),pisps.size());
 				
@@ -211,20 +211,20 @@ public class Validator {
 				{
 
 					@Override
-					public void onSuccess(List<AlgorithmRun> runs) {
+					public void onSuccess(List<AlgorithmRunResult> runs) {
 						
-						Map<RunConfig, AlgorithmRun> runsToRunConfig = new HashMap<RunConfig, AlgorithmRun>();
+						Map<AlgorithmRunConfiguration, AlgorithmRunResult> runsToRunConfig = new HashMap<AlgorithmRunConfiguration, AlgorithmRunResult>();
 						
-						for(AlgorithmRun run : runs)
+						for(AlgorithmRunResult run : runs)
 						{
-							runsToRunConfig.put(run.getRunConfig(),run);
+							runsToRunConfig.put(run.getAlgorithmRunConfiguration(),run);
 						}
 						
-						for(Entry<WaitableTAECallback, List<RunConfig>> ent : callbacksToSchedule.entrySet())
+						for(Entry<WaitableTAECallback, List<AlgorithmRunConfiguration>> ent : callbacksToSchedule.entrySet())
 						{
 						
-							List<AlgorithmRun> runsToNotify = new ArrayList<AlgorithmRun>();
-							for(RunConfig rc : ent.getValue())
+							List<AlgorithmRunResult> runsToNotify = new ArrayList<AlgorithmRunResult>();
+							for(AlgorithmRunConfiguration rc : ent.getValue())
 							{
 								runsToNotify.add(runsToRunConfig.get(rc));
 							}
@@ -321,9 +321,13 @@ public class Validator {
 	
 	
 	
-	private ValidationRuns  validateStage(List<ProblemInstanceSeedPair> pisps, final ValidationOptions options,final double cutoffTime, 
+	private ValidationRuns  validateStage(final List<ProblemInstanceSeedPair> pisps, final ValidationOptions options,final double cutoffTime, 
 		final RunObjective runObj,
-		final OverallObjective intraInstanceObjective, final OverallObjective interInstanceObjective,  final TrajectoryFile trajFile, final AlgorithmExecutionConfig execConfig) 
+
+//		final OverallObjective intraInstanceObjective, final OverallObjective interInstanceObjective,  final List<TrajectoryFileEntry> tfes, final long numRun, boolean waitForRuns, AlgorithmExecutionConfig execConfig,int cores) 
+
+		final OverallObjective intraInstanceObjective, final OverallObjective interInstanceObjective,  final TrajectoryFile trajFile, AlgorithmExecutionConfiguration execConfig) 
+
 		{
 
 	
@@ -341,13 +345,13 @@ public class Validator {
 		if(options.validateOnlyIfWallTimeReached > maxWallTimeStamp)
 		{
 			log.info("Maximum walltime was {} but we required {} seconds to have passed validating ", maxWallTimeStamp, options.validateOnlyIfWallTimeReached );
-			return new ValidationRuns(new TreeMap<TrajectoryFileEntry,Double>());
+			return new ValidationRuns(new TreeMap<TrajectoryFileEntry,ValidationResult>());
 		}
 		
 		if(options.validateOnlyIfTunerTimeReached > maxTunerTimeStamp)
 		{
 			log.info("Maximum Tuner Time was {} but we required {} seconds to have passed before validating ", maxTunerTimeStamp, options.validateOnlyIfTunerTimeReached );
-			return new ValidationRuns(new TreeMap<TrajectoryFileEntry,Double>());
+			return new ValidationRuns(new TreeMap<TrajectoryFileEntry,ValidationResult>());
 		}
 		
 		
@@ -406,7 +410,7 @@ public class Validator {
 			{
 				maxTimestamp = skipList.floorKey(Double.MAX_VALUE);
 			}
-			ParamConfiguration lastConfig = null;
+			ParameterConfiguration lastConfig = null;
 			Double lastPerformance = Double.MAX_VALUE;
 			for(double x = maxTimestamp; x > options.minTimestamp ; x /= options.multFactor)
 			{
@@ -448,10 +452,11 @@ public class Validator {
 		
 		final List<TrajectoryFileEntry> tfesToRun = new ArrayList<TrajectoryFileEntry>(tfesToUse.size());
 		tfesToRun.addAll(tfesToUse);
+				
 		
-		Set<ParamConfiguration> configs = new LinkedHashSet<ParamConfiguration>();
+		Set<ParameterConfiguration> configs = new LinkedHashSet<ParameterConfiguration>();
 		
-		final Map<ParamConfiguration, Integer> configToID = new LinkedHashMap<ParamConfiguration, Integer>();
+		final Map<ParameterConfiguration, Integer> configToID = new LinkedHashMap<ParameterConfiguration, Integer>();
 		
 		int id=1;
 		for(TrajectoryFileEntry tfe : tfesToRun)
@@ -462,8 +467,9 @@ public class Validator {
 			}
 		}
 		
+
 		
-		List<RunConfig> runConfigs = getRunConfigs(configs, pisps, cutoffTime);
+		List<AlgorithmRunConfiguration> runConfigs = getRunConfigs(configs, pisps, cutoffTime,execConfig);
 		
 		
 		
@@ -472,19 +478,19 @@ public class Validator {
 		
 		final AtomicReference<RuntimeException> exception = new AtomicReference<RuntimeException>();
 		
-		final SortedMap<TrajectoryFileEntry, Double> finalPerformance = new ConcurrentSkipListMap<TrajectoryFileEntry, Double>();
+		final SortedMap<TrajectoryFileEntry, ValidationResult> finalPerformance = new ConcurrentSkipListMap<TrajectoryFileEntry, ValidationResult>();
 		
 		WaitableTAECallback callback = new WaitableTAECallback(new TargetAlgorithmEvaluatorCallback()
 		{
 
 			@Override
-			public void onSuccess(List<AlgorithmRun> runs) {
+			public void onSuccess(List<AlgorithmRunResult> runs) {
 				// TODO Auto-generated method stub
 				
 				
 				
 				try {
-					writeConfigurationMapFile(trajFile, options, configToID, execConfig, runs);
+					writeConfigurationMapFile(trajFile, options, configToID,  runs);
 				} catch(IOException e)
 				{
 					log.error("Could not write results file", e);
@@ -501,12 +507,12 @@ public class Validator {
 				
 				try
 				{
-					Map<ParamConfiguration, Double> testSetPerformance = writeInstanceResultFile(runs, options, cutoffTime, runObj, intraInstanceObjective, interInstanceObjective, trajFile, configToID);
+					Map<ParameterConfiguration, Double> testSetPerformance = writeInstanceResultFile(runs, options, cutoffTime, runObj, intraInstanceObjective, interInstanceObjective, trajFile, configToID);
 					
 					
 					for(TrajectoryFileEntry tfe : tfesToRun)
 					{
-						finalPerformance.put(tfe, testSetPerformance.get(tfe.getConfiguration()));
+						finalPerformance.put(tfe, new ValidationResult(testSetPerformance.get(tfe.getConfiguration()), pisps));
 					}
 					
 					if(runs.size() > 0)
@@ -523,24 +529,24 @@ public class Validator {
 				
 				
 				try {
-					ConcurrentHashMap<ParamConfiguration, Map<ProblemInstanceSeedPair, AlgorithmRun>> matrixRuns = new ConcurrentHashMap<ParamConfiguration, Map<ProblemInstanceSeedPair, AlgorithmRun>>();
+					ConcurrentHashMap<ParameterConfiguration, Map<ProblemInstanceSeedPair, AlgorithmRunResult>> matrixRuns = new ConcurrentHashMap<ParameterConfiguration, Map<ProblemInstanceSeedPair, AlgorithmRunResult>>();
 					
-					for(AlgorithmRun run : runs)
+					for(AlgorithmRunResult run : runs)
 					{
-						matrixRuns.putIfAbsent(run.getRunConfig().getParamConfiguration(), new HashMap<ProblemInstanceSeedPair, AlgorithmRun>());
+						matrixRuns.putIfAbsent(run.getAlgorithmRunConfiguration().getParameterConfiguration(), new TreeMap<ProblemInstanceSeedPair, AlgorithmRunResult>());
 						
-						Map<ProblemInstanceSeedPair, AlgorithmRun> configRuns = matrixRuns.get(run.getRunConfig().getParamConfiguration());
+						Map<ProblemInstanceSeedPair, AlgorithmRunResult> configRuns = matrixRuns.get(run.getAlgorithmRunConfiguration().getParameterConfiguration());
 						
-						configRuns.put(run.getRunConfig().getProblemInstanceSeedPair(), run);
+						configRuns.put(run.getAlgorithmRunConfiguration().getProblemInstanceSeedPair(), run);
 					}
 					
 					
-					List<ParamConfiguration> configs = new ArrayList<ParamConfiguration>();
+					List<ParameterConfiguration> configs = new ArrayList<ParameterConfiguration>();
 					
-					for(AlgorithmRun run : runs)
+					for(AlgorithmRunResult run : runs)
 					{
-						if(configs.contains(run.getRunConfig().getParamConfiguration())) continue;
-						configs.add(run.getRunConfig().getParamConfiguration());
+						if(configs.contains(run.getAlgorithmRunConfiguration().getParameterConfiguration())) continue;
+						configs.add(run.getAlgorithmRunConfiguration().getParameterConfiguration());
 					}
 					
 					
@@ -646,9 +652,9 @@ public class Validator {
 	
 	public static class ValidationRuns
 	{
-		List<RunConfig> runConfigs;
+		List<AlgorithmRunConfiguration> runConfigs;
 		WaitableTAECallback callback;
-		private SortedMap<TrajectoryFileEntry, Double> result;
+		private SortedMap<TrajectoryFileEntry, ValidationResult> result;
 		private AtomicReference<RuntimeException> exception;
 	
 		
@@ -656,14 +662,14 @@ public class Validator {
 		
 		public boolean done;
 		
-		public ValidationRuns(SortedMap<TrajectoryFileEntry, Double> result)
+		public ValidationRuns(SortedMap<TrajectoryFileEntry, ValidationResult> result)
 		{
 			this.result = result; 
 			this.runConfigs = Collections.emptyList();
 			done = true;
 		}
 		
-		public ValidationRuns(List<RunConfig> runConfigs, WaitableTAECallback callback, AtomicReference<RuntimeException> exception,SortedMap<TrajectoryFileEntry, Double> result)
+		public ValidationRuns(List<AlgorithmRunConfiguration> runConfigs, WaitableTAECallback callback, AtomicReference<RuntimeException> exception,SortedMap<TrajectoryFileEntry, ValidationResult> result)
 		{
 			this.runConfigs = runConfigs; 
 			this.callback = callback;
@@ -674,19 +680,16 @@ public class Validator {
 	}
 	
 
-private List<RunConfig> getRunConfigs(Set<ParamConfiguration> configs, List<ProblemInstanceSeedPair> pisps, double cutoffTime) 
+
+private List<AlgorithmRunConfiguration> getRunConfigs(Set<ParameterConfiguration> configs, List<ProblemInstanceSeedPair> pisps, double cutoffTime,AlgorithmExecutionConfiguration execConfig) 
 {
 	
-	
-	
-	
-	
-	List<RunConfig> runConfigs  = new ArrayList<RunConfig>(pisps.size()*configs.size());
-	for(ParamConfiguration config: configs)
+	List<AlgorithmRunConfiguration> runConfigs  = new ArrayList<AlgorithmRunConfiguration>(pisps.size()*configs.size());
+	for(ParameterConfiguration config: configs)
 	{
 		for(ProblemInstanceSeedPair pisp : pisps)
 		{
-			runConfigs.add(new RunConfig(pisp, cutoffTime,config));
+			runConfigs.add(new AlgorithmRunConfiguration(pisp, cutoffTime,config,execConfig));
 		}
 	}
 	
@@ -770,12 +773,12 @@ endloop:
 	}
 
 	
-	private static void writeConfigurationMapFile(TrajectoryFile trajFile, ValidationOptions validationOptions,	Map<ParamConfiguration, Integer> configToID,AlgorithmExecutionConfig execConfig, List<AlgorithmRun> runs) throws IOException {
+	private static void writeConfigurationMapFile(TrajectoryFile trajFile, ValidationOptions validationOptions,	Map<ParameterConfiguration, Integer> configToID, List<AlgorithmRunResult> runs) throws IOException {
 		// TODO Auto-generated method stub
 		File f = getFile(trajFile, "validationCallStrings",validationOptions.outputFileSuffix,"csv");
 		// new File(outputDir + File.separator +  "validationInstanceSeedResult"+suffix+"-run" + numRun + ".csv");
 
-		log.debug("Instance Seed Result File Written to: {}", f.getAbsolutePath());
+		log.info("Validation Call Strings written to: {}", f.getAbsolutePath());
 		CSVWriter writer = new CSVWriter(new FileWriter(f));
 		
 		
@@ -795,19 +798,19 @@ endloop:
 		
 		//sbValidation.append(time).append(",").append(empiricalPerformance).append(",").append(testSetPerformance).append(",").append(acOverhead).append(",\"").append(idMap.get(rc.getParamConfiguration())).append("\",\n");
 		
-		for(Entry<ParamConfiguration, Integer> ent : configToID.entrySet())
+		for(Entry<ParameterConfiguration, Integer> ent : configToID.entrySet())
 		{
-			RunConfig rc = null;
+			AlgorithmRunConfiguration rc = null;
 			
-			for(AlgorithmRun run : runs)
+			for(AlgorithmRunResult run : runs)
 			{
-				if (run.getRunConfig().getParamConfiguration().equals(ent.getKey()))
+				if (run.getAlgorithmRunConfiguration().getParameterConfiguration().equals(ent.getKey()))
 				{
-					rc = run.getRunConfig();
+					rc = run.getAlgorithmRunConfiguration();
 					break;
 				}
 			}
-			String[] args = {String.valueOf(ent.getValue()), ent.getKey().getFormattedParamString(StringFormat.NODB_SYNTAX), CommandLineAlgorithmRun.getTargetAlgorithmExecutionCommandAsString(execConfig, rc) };
+			String[] args = {String.valueOf(ent.getValue()), ent.getKey().getFormattedParameterString(ParameterStringFormat.NODB_SYNTAX), CommandLineAlgorithmRun.getTargetAlgorithmExecutionCommandAsString( rc) };
 			writer.writeNext(args);
 		}
 		
@@ -820,33 +823,126 @@ endloop:
 	 * @param tfes
 	 * @throws IOException 
 	 */
-	private static void writeConfigurationResultsMatrix( List<ParamConfiguration> inOrderConfigs, 
-			ConcurrentHashMap<ParamConfiguration, Map<ProblemInstanceSeedPair, AlgorithmRun>> matrixRuns,
-			List<TrajectoryFileEntry> tfes, ValidationOptions validationOptions,TrajectoryFile trajFile, RunObjective runObj, Map<ParamConfiguration, Integer> idMap) throws IOException {
+	private static void writeConfigurationResultsMatrix( List<ParameterConfiguration> inOrderConfigs, 
+			ConcurrentHashMap<ParameterConfiguration, Map<ProblemInstanceSeedPair, AlgorithmRunResult>> matrixRuns,
+			List<TrajectoryFileEntry> tfes, ValidationOptions validationOptions,TrajectoryFile trajFile, RunObjective runObj, Map<ParameterConfiguration, Integer> idMap) throws IOException {
 
 
 		
-		File configurationObjective =  getFile(trajFile, "configurationObjectiveMatrix",validationOptions.outputFileSuffix,"csv");
-		File configurationRun =  getFile(trajFile, "configurationRunMatrix",validationOptions.outputFileSuffix,"csv");
+		File configurationObjective =  getFile(trajFile, "validationObjectiveMatrix",validationOptions.outputFileSuffix,"csv");
+		File configurationRun =  getFile(trajFile, "validationRunResultLineMatrix",validationOptions.outputFileSuffix,"csv");
 		
-		
-				// new File(outputDir +  File.separator + "configurationMatrix"+suffix+"-run" + numRun + ".csv");
-		log.debug("Validation Configuration/PISP Matrix of objectives Written to: {}", configurationObjective.getAbsolutePath());
-		log.debug("Validation Configuration/PISP Matrix of runs Written to: {}", configurationRun.getAbsolutePath());
+		log.info("Validation matrix of objectives for cross-product of configurations and (instance,seed) pairs written to: {}", configurationObjective.getAbsolutePath());
+		log.info("Validation matrix of complete run result line for cross-product of configurations and (instance,seed) pairs written to: {}", configurationRun.getAbsolutePath());
 		
 		CSVWriter objectiveMatrixCSV = new CSVWriter(new FileWriter(configurationObjective));
 		CSVWriter runMatrixCSV = new CSVWriter(new FileWriter(configurationRun));
+		
+		
 		try {
+			TreeMap<ProblemInstanceSeedPair, Map<ParameterConfiguration, AlgorithmRunResult>> transposedMap = new TreeMap<>();
+			
+			
+			for(Map<ProblemInstanceSeedPair, AlgorithmRunResult> ent : matrixRuns.values())
+			{
+				
+				for(AlgorithmRunResult run : ent.values())
+				{
+					if(transposedMap.get(run.getProblemInstanceSeedPair()) == null)
+					{
+						transposedMap.put(run.getProblemInstanceSeedPair(), new ConcurrentHashMap<ParameterConfiguration, AlgorithmRunResult>());
+					}
+					
+					
+					
+					transposedMap.get(run.getProblemInstanceSeedPair()).put(run.getParameterConfiguration(), run);
+				}
+			}
+			
+			ArrayList<String> runMatrixHeaderRow = new ArrayList<String>();
+			ArrayList<String> objectiveMatrixHeaderRow = new ArrayList<String>();
+			
+
+			runMatrixHeaderRow.add("Problem Instance");
+			runMatrixHeaderRow.add("Seed");
+			objectiveMatrixHeaderRow.add("Problem Instance");
+			objectiveMatrixHeaderRow.add("Seed");
+			
+			for(ParameterConfiguration config : inOrderConfigs)
+			{
+				runMatrixHeaderRow.add("Run result line of validation config #" + String.valueOf(idMap.get(config)));
+				objectiveMatrixHeaderRow.add("Objective of validation config #" + String.valueOf(idMap.get(config)));
+			}
+			
+			/*
+			for(ProblemInstanceSeedPair pisp : pisps)
+			{
+				headerRow.add(pisp.getProblemInstance().getInstanceName() + "," + pisp.getSeed());
+			}*/
+			
+			String[] header = objectiveMatrixHeaderRow.toArray(new String[0]);
+			
+			objectiveMatrixCSV.writeNext(header);
+			
+			header = runMatrixHeaderRow.toArray(new String[0]);
+			runMatrixCSV.writeNext(header);
+			
+			
+			for(Entry<ProblemInstanceSeedPair, Map<ParameterConfiguration, AlgorithmRunResult>> ent : transposedMap.entrySet())
+			{
+				
+				ArrayList<String> objectiveRow = new ArrayList<String>();
+				ArrayList<String> resultLineRow = new ArrayList<String>();
+				
+				objectiveRow.add(ent.getKey().getProblemInstance().getInstanceName());
+				
+				resultLineRow.add(ent.getKey().getProblemInstance().getInstanceName());
+				
+				
+				objectiveRow.add(String.valueOf(ent.getKey().getSeed()));
+				resultLineRow.add(String.valueOf(ent.getKey().getSeed()));
+				
+				
+				
+				for(ParameterConfiguration config : inOrderConfigs)
+				{
+					
+					AlgorithmRunResult run = ent.getValue().get(config);
+					if(run == null)
+					{
+						throw new IllegalStateException("Expected all configurations to have the exact same pisps");
+					}
+					
+					if(!run.getAlgorithmRunConfiguration().getProblemInstanceSeedPair().equals(ent.getKey()))
+					{
+						throw new IllegalStateException("DataStructure corruption detected ");
+					}
+					
+					objectiveRow.add(String.valueOf(runObj.getObjective(run)));
+					resultLineRow.add(run.getResultLine());
+				}
+				
+				
+				
+				
+				String[] nextRow = objectiveRow.toArray(new String[0]);
+				String[] nextRunRow = resultLineRow.toArray(new String[0]);
+				
+				objectiveMatrixCSV.writeNext(nextRow);
+				runMatrixCSV.writeNext(nextRunRow);
+				
+			}
+			/*
 			List<ProblemInstanceSeedPair> pisps = new ArrayList<ProblemInstanceSeedPair>();
 
-			Set<ParamConfiguration> doneConfigs = new HashSet<ParamConfiguration>();
+			Set<ParameterConfiguration> doneConfigs = new HashSet<ParameterConfiguration>();
 			
-			for(ParamConfiguration config : inOrderConfigs)
+			for(ParameterConfiguration config : inOrderConfigs)
 			{
 				
 				if(doneConfigs.contains(config)) continue;
 				doneConfigs.add(config);
-				Map<ProblemInstanceSeedPair, AlgorithmRun> runs = matrixRuns.get(config);
+				Map<ProblemInstanceSeedPair, AlgorithmRunResult> runs = matrixRuns.get(config);
 	
 				if(runs == null) continue;
 				if(pisps.isEmpty())
@@ -860,12 +956,12 @@ endloop:
 								public int compare(ProblemInstanceSeedPair o1,
 										ProblemInstanceSeedPair o2) {
 									
-									if(o1.getInstance().equals(o2.getInstance()))
+									if(o1.getProblemInstance().equals(o2.getProblemInstance()))
 									{
 										return (int) Math.signum(o1.getSeed() - o2.getSeed());
 									} else
 									{
-										return o1.getInstance().getInstanceID() - o2.getInstance().getInstanceID();
+										return o1.getProblemInstance().getInstanceID() - o2.getProblemInstance().getInstanceID();
 									}
 									
 									
@@ -879,7 +975,7 @@ endloop:
 					headerRow.add("Validation Configuration ID");
 					for(ProblemInstanceSeedPair pisp : pisps)
 					{
-						headerRow.add(pisp.getInstance().getInstanceName() + "," + pisp.getSeed());
+						headerRow.add(pisp.getProblemInstance().getInstanceName() + "," + pisp.getSeed());
 					}
 					
 					String[] header = headerRow.toArray(new String[0]);
@@ -898,13 +994,13 @@ endloop:
 				
 				for(ProblemInstanceSeedPair pisp : pisps)
 				{
-					AlgorithmRun run = runs.get(pisp);
+					AlgorithmRunResult run = runs.get(pisp);
 					if(run == null)
 					{
 						throw new IllegalStateException("Expected all configurations to have the exact same pisps");
 					}
 					
-					if(!run.getRunConfig().getProblemInstanceSeedPair().equals(pisp))
+					if(!run.getAlgorithmRunConfiguration().getProblemInstanceSeedPair().equals(pisp))
 					{
 						throw new IllegalStateException("DataStructure corruption detected ");
 					}
@@ -920,7 +1016,7 @@ endloop:
 				objectiveMatrixCSV.writeNext(nextRow);
 				runMatrixCSV.writeNext(nextRunRow);
 			}
-			
+			*/
 			
 		} finally
 		{
@@ -944,48 +1040,48 @@ endloop:
 	 * @return - Overall objective over test set (For convinence)
 	 * @throws IOException
 	 */
-	private static Map<ParamConfiguration, Double> writeInstanceResultFile(List<AlgorithmRun> runs, ValidationOptions validationOptions, double cutoffTime,  RunObjective runObj, OverallObjective intraInstanceObjective, OverallObjective interInstanceObjective, TrajectoryFile trajFile, Map<ParamConfiguration, Integer> configIDToMap) throws IOException 
+	private static Map<ParameterConfiguration, Double> writeInstanceResultFile(List<AlgorithmRunResult> runs, ValidationOptions validationOptions, double cutoffTime,  RunObjective runObj, OverallObjective intraInstanceObjective, OverallObjective interInstanceObjective, TrajectoryFile trajFile, Map<ParameterConfiguration, Integer> configIDToMap) throws IOException 
 	{
 		
 		File f =  getFile(trajFile,  "validationPerformanceDebug",validationOptions.outputFileSuffix,"csv");
 		//new File(outputDir +  File.separator + "validationResultsMatrix"+suffix+"-run" + numRun + ".csv");
-		log.debug("Instance Validation Matrix Result Written to: {}", f.getAbsolutePath());
+		log.info("Instance performance (for debug) written to: {}", f.getAbsolutePath());
 		
 		CSVWriter writer = new CSVWriter(new FileWriter(f));
 		
-		Map<ParamConfiguration, Double> calculatedOverallObjectives = new LinkedHashMap<ParamConfiguration, Double>();
+		Map<ParameterConfiguration, Double> calculatedOverallObjectives = new LinkedHashMap<ParameterConfiguration, Double>();
 	
 		
-		Map<ParamConfiguration, List<AlgorithmRun>> configToRunMap = new LinkedHashMap<ParamConfiguration, List<AlgorithmRun>>();
+		Map<ParameterConfiguration, List<AlgorithmRunResult>> configToRunMap = new LinkedHashMap<ParameterConfiguration, List<AlgorithmRunResult>>();
 		
-		for(AlgorithmRun run : runs)
+		for(AlgorithmRunResult run : runs)
 		{
-			ParamConfiguration config = run.getRunConfig().getParamConfiguration();
+			ParameterConfiguration config = run.getAlgorithmRunConfiguration().getParameterConfiguration();
 			if(configToRunMap.get(config) == null)
 			{
-				configToRunMap.put(config, new ArrayList<AlgorithmRun>(1000));
+				configToRunMap.put(config, new ArrayList<AlgorithmRunResult>(1000));
 			}
 			configToRunMap.get(config).add(run);
 			
 		}
 		
-		for(Entry<ParamConfiguration, List<AlgorithmRun>> ent : configToRunMap.entrySet())
+		for(Entry<ParameterConfiguration, List<AlgorithmRunResult>> ent : configToRunMap.entrySet())
 		{
-			Map<ProblemInstance, List<AlgorithmRun>> map = new LinkedHashMap<ProblemInstance,List<AlgorithmRun>>();
+			Map<ProblemInstance, List<AlgorithmRunResult>> map = new LinkedHashMap<ProblemInstance,List<AlgorithmRunResult>>();
 			
 			runs = ent.getValue();
 			
 			
 			int maxRunLength =0;
-			for(AlgorithmRun run : runs)
+			for(AlgorithmRunResult run : runs)
 			{
-				ProblemInstance pi = run.getRunConfig().getProblemInstanceSeedPair().getInstance();
+				ProblemInstance pi = run.getAlgorithmRunConfiguration().getProblemInstanceSeedPair().getProblemInstance();
 				if(map.get(pi) == null)
 				{
-					map.put(pi, new ArrayList<AlgorithmRun>());
+					map.put(pi, new ArrayList<AlgorithmRunResult>());
 				}
 				
-				List<AlgorithmRun> myRuns = map.get(pi);
+				List<AlgorithmRunResult> myRuns = map.get(pi);
 				
 				
 				myRuns.add(run);
@@ -1010,12 +1106,12 @@ endloop:
 			List<Double> overallObjectives = new ArrayList<Double>();
 			
 			
-			for(Entry<ProblemInstance, List<AlgorithmRun>> piRuns : map.entrySet())
+			for(Entry<ProblemInstance, List<AlgorithmRunResult>> piRuns : map.entrySet())
 			{
 				List<String> outputLine = new ArrayList<String>();
 				outputLine.add("");
 				outputLine.add(piRuns.getKey().getInstanceName());
-				List<AlgorithmRun> myRuns = piRuns.getValue();
+				List<AlgorithmRunResult> myRuns = piRuns.getValue();
 				
 				
 	
@@ -1030,7 +1126,7 @@ endloop:
 				outputLine.add(String.valueOf(overallResult));
 				
 				overallObjectives.add(overallResult);
-				for(AlgorithmRun run : piRuns.getValue())
+				for(AlgorithmRunResult run : piRuns.getValue())
 				{
 					outputLine.add(String.valueOf(runObj.getObjective(run)));
 				}
@@ -1075,17 +1171,23 @@ endloop:
 		}
 	
 		
-		File f = new File(trajFile.getLocation().getParent() + File.separator + filename +"-" + baseName + suffix+"."+extension.replaceAll(Matcher.quoteReplacement("\\."), ""));
-		return f;
+		if(trajFile.getLocation().getParent() != null)
+		{
+			return new File(trajFile.getLocation().getParent() + File.separator + filename +"-" + baseName + suffix+"."+extension.replaceAll(Matcher.quoteReplacement("\\."), ""));
+		} else
+		{
+			return new File(filename +"-" + baseName + suffix+"."+extension.replaceAll(Matcher.quoteReplacement("\\."), ""));
+		}
+		
 				
 	}
 	
-	private void appendInstanceResultFile(Map<TrajectoryFileEntry, Double> finalPerformance, TrajectoryFile trajFile, ValidationOptions validationOptions, boolean useWallTime,  Map<ParamConfiguration, Integer> idMap) throws IOException {
+	private void appendInstanceResultFile(Map<TrajectoryFileEntry, ValidationResult> finalPerformance, TrajectoryFile trajFile, ValidationOptions validationOptions, boolean useWallTime,  Map<ParameterConfiguration, Integer> idMap) throws IOException {
 		
 		
 		File validationFile = getFile(trajFile,  "validationResults",validationOptions.outputFileSuffix,"csv");
 		
-		log.debug("Validation Results File Written to: {}", validationFile.getAbsolutePath());
+		log.info("Main validation results file written to: {}", validationFile.getAbsolutePath());
 		
 		if(!validationFile.exists())
 		{
@@ -1102,7 +1204,7 @@ endloop:
 		
 		StringBuilder sbValidation = new StringBuilder("\"Time\",\"Training (Empirical) Performance\",\"Test Set Performance\",\"AC Overhead Time\",\"Validation Configuration ID\",\n");
 		
-		for(Entry<TrajectoryFileEntry, Double > ent : finalPerformance.entrySet())
+		for(Entry<TrajectoryFileEntry, ValidationResult > ent : finalPerformance.entrySet())
 		{
 			double time;
 					
@@ -1115,7 +1217,7 @@ endloop:
 			}
 			
 			double empiricalPerformance = ent.getKey().getEmpericalPerformance();
-			double testSetPerformance = ent.getValue();
+			double testSetPerformance = ent.getValue().getPerformance();
 			double acOverhead = ent.getKey().getACOverhead();
 				
 			sbValidation.append(time).append(",").append(empiricalPerformance).append(",").append(testSetPerformance).append(",").append(acOverhead).append(",\"").append(idMap.get(ent.getKey().getConfiguration())).append("\",\n");
@@ -1136,10 +1238,10 @@ endloop:
 		
 }
 	
-	private static void writeLegacyStateFile( String suffix, List<AlgorithmRun> runs, TrajectoryFile trajFile, OverallObjective interRunObjective, OverallObjective intraRunObjective, RunObjective runObj)
+	private static void writeLegacyStateFile( String suffix, List<AlgorithmRunResult> runs, TrajectoryFile trajFile, OverallObjective interRunObjective, OverallObjective intraRunObjective, RunObjective runObj)
 	{
 		RunHistory rh = new NewRunHistory( interRunObjective, intraRunObjective, runObj);
-		for(AlgorithmRun run : runs)
+		for(AlgorithmRunResult run : runs)
 		{
 			try {
 				rh.append(run);
